# Growtopia Private Server Controler
> Module For Controle Your GTPS | Build in Python3

## Creator Information
- iFanPS DB:
    - Name : `iRfan`
    - Age : `17`
    - Come From: `Mars`

- NumeX DB:
    - Name : `Christian`
    - Age : `19`
    - Come From : `Mars`

## Installing Module
```bash
> pip install pscontroler
```

## Basic Configuration
```bash
> Make Sure You Already install a Python3
> Install The Module
```

## list Worker
```bash
> Status (See server status)
> Online (See online player)
> Player (See player account total)
> World (See total worlds created)
> Start (Start the Server)
> Stop (Stop the server)
> Givepgems (Give player gems)
> Giveplevel (Give player level)
> Giveproles (Give player roles)
> Countsize_Pwfolder (Count player and world folder size)
> Maintactive and Deactive (Maintenance activator and deactive)
> Pdelete (Delete player data)
> Wdelete (Delete world)
```

## To Do list
- Command:
    - Auto Backup